==> vala-0.5.1.tar.bz2: vala-0.5.1/ccode/valaccodegotostatement.c <==
/* valaccodegotostatement.vala
 *
 * Copyright (C) 2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <ccode/valaccodegotostatement.h>
#include <ccode/valaccodelinedirective.h>




struct _ValaCCodeGotoStatementPrivate {
	char* _name;
};

#define VALA_CCODE_GOTO_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_GOTO_STATEMENT, ValaCCodeGotoStatementPrivate))
enum  {
	VALA_CCODE_GOTO_STATEMENT_DUMMY_PROPERTY
};
static void vala_ccode_goto_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_goto_statement_parent_class = NULL;
static void vala_ccode_goto_statement_finalize (ValaCCodeNode* obj);



ValaCCodeGotoStatement* vala_ccode_goto_statement_construct (GType object_type, const char* name) {
	ValaCCodeGotoStatement* self;
	g_return_val_if_fail (name != NULL, NULL);
	self = ((ValaCCodeGotoStatement*) (g_type_create_instance (object_type)));
	vala_ccode_goto_statement_set_name (self, name);
	return self;
}


ValaCCodeGotoStatement* vala_ccode_goto_statement_new (const char* name) {
	return vala_ccode_goto_statement_construct (VALA_TYPE_CCODE_GOTO_STATEMENT, name);
}


static void vala_ccode_goto_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
	ValaCCodeGotoStatement * self;
	self = ((ValaCCodeGotoStatement*) (base));
	g_return_if_fail (writer != NULL);
	vala_ccode_writer_write_indent (writer, NULL);
	vala_ccode_writer_write_string (writer, "goto ");
	vala_ccode_writer_write_string (writer, self->priv->_name);
	vala_ccode_writer_write_string (writer, ";");
	vala_ccode_writer_write_newline (writer);
}


const char* vala_ccode_goto_statement_get_name (ValaCCodeGotoStatement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return self->priv->_name;
}


void vala_ccode_goto_statement_set_name (ValaCCodeGotoStatement* self, const char* value) {
	char* _tmp2;
	const char* _tmp1;
	g_return_if_fail (self != NULL);
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
}


static void vala_ccode_goto_statement_class_init (ValaCCodeGotoStatementClass * klass) {
	vala_ccode_goto_statement_parent_class = g_type_class_peek_parent (klass);
	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_goto_statement_finalize;
	g_type_class_add_private (klass, sizeof (ValaCCodeGotoStatementPrivate));
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_goto_statement_real_write;
}


static void vala_ccode_goto_statement_instance_init (ValaCCodeGotoStatement * self) {
	self->priv = VALA_CCODE_GOTO_STATEMENT_GET_PRIVATE (self);
}


static void vala_ccode_goto_statement_finalize (ValaCCodeNode* obj) {
	ValaCCodeGotoStatement * self;
	self = VALA_CCODE_GOTO_STATEMENT (obj);
	self->priv->_name = (g_free (self->priv->_name), NULL);
	VALA_CCODE_NODE_CLASS (vala_ccode_goto_statement_parent_class)->finalize (obj);
}


GType vala_ccode_goto_statement_get_type (void) {
	static GType vala_ccode_goto_statement_type_id = 0;
	if (vala_ccode_goto_statement_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeGotoStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_goto_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeGotoStatement), 0, (GInstanceInitFunc) vala_ccode_goto_statement_instance_init, NULL };
		vala_ccode_goto_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeGotoStatement", &g_define_type_info, 0);
	}
	return vala_ccode_goto_statement_type_id;
}

==> vala-0.5.2.tar.bz2: vala-0.5.2/ccode/valaccodegotostatement.c <==
/* valaccodegotostatement.vala
 *
 * Copyright (C) 2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <ccode/valaccodegotostatement.h>
#include <ccode/valaccodelinedirective.h>




struct _ValaCCodeGotoStatementPrivate {
	char* _name;
};

#define VALA_CCODE_GOTO_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_GOTO_STATEMENT, ValaCCodeGotoStatementPrivate))
enum  {
	VALA_CCODE_GOTO_STATEMENT_DUMMY_PROPERTY
};
static void vala_ccode_goto_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_goto_statement_parent_class = NULL;
static void vala_ccode_goto_statement_finalize (ValaCCodeNode* obj);



ValaCCodeGotoStatement* vala_ccode_goto_statement_construct (GType object_type, const char* name) {
	ValaCCodeGotoStatement* self;
	g_return_val_if_fail (name != NULL, NULL);
	self = (ValaCCodeGotoStatement*) g_type_create_instance (object_type);
	vala_ccode_goto_statement_set_name (self, name);
	return self;
}


ValaCCodeGotoStatement* vala_ccode_goto_statement_new (const char* name) {
	return vala_ccode_goto_statement_construct (VALA_TYPE_CCODE_GOTO_STATEMENT, name);
}


static void vala_ccode_goto_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
	ValaCCodeGotoStatement * self;
	self = (ValaCCodeGotoStatement*) base;
	g_return_if_fail (writer != NULL);
	vala_ccode_writer_write_indent (writer, NULL);
	vala_ccode_writer_write_string (writer, "goto ");
	vala_ccode_writer_write_string (writer, self->priv->_name);
	vala_ccode_writer_write_string (writer, ";");
	vala_ccode_writer_write_newline (writer);
}


const char* vala_ccode_goto_statement_get_name (ValaCCodeGotoStatement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return self->priv->_name;
}


void vala_ccode_goto_statement_set_name (ValaCCodeGotoStatement* self, const char* value) {
	char* _tmp2;
	const char* _tmp1;
	g_return_if_fail (self != NULL);
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2);
}


static void vala_ccode_goto_statement_class_init (ValaCCodeGotoStatementClass * klass) {
	vala_ccode_goto_statement_parent_class = g_type_class_peek_parent (klass);
	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_goto_statement_finalize;
	g_type_class_add_private (klass, sizeof (ValaCCodeGotoStatementPrivate));
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_goto_statement_real_write;
}


static void vala_ccode_goto_statement_instance_init (ValaCCodeGotoStatement * self) {
	self->priv = VALA_CCODE_GOTO_STATEMENT_GET_PRIVATE (self);
}


static void vala_ccode_goto_statement_finalize (ValaCCodeNode* obj) {
	ValaCCodeGotoStatement * self;
	self = VALA_CCODE_GOTO_STATEMENT (obj);
	self->priv->_name = (g_free (self->priv->_name), NULL);
	VALA_CCODE_NODE_CLASS (vala_ccode_goto_statement_parent_class)->finalize (obj);
}


GType vala_ccode_goto_statement_get_type (void) {
	static GType vala_ccode_goto_statement_type_id = 0;
	if (vala_ccode_goto_statement_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeGotoStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_goto_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeGotoStatement), 0, (GInstanceInitFunc) vala_ccode_goto_statement_instance_init, NULL };
		vala_ccode_goto_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeGotoStatement", &g_define_type_info, 0);
	}
	return vala_ccode_goto_statement_type_id;
}
